@@ -37,13 +37,11 @@ import android.database.sqlite.SQLiteDatabase;
 import android.net.Uri;
 import android.os.Environment;
 import android.os.StatFs;
-import android.preference.PreferenceManager;
 import android.support.v4.content.ContextCompat;
 import android.util.Log;
 
 import com.rareventure.android.AndroidPreferenceSet;
 import com.rareventure.android.AndroidPreferenceSet.AndroidPreferences;
-import com.rareventure.android.SuperThreadManager;
 import com.rareventure.android.Util;
 import com.rareventure.android.database.DbDatastoreAccessor;
 import com.rareventure.android.database.timmy.RollBackTimmyDatastoreAccessor;
@@ -745,8 +743,8 @@ public class GTG {
 					GTG.prefs.useMetric);
 			res.put(/* ttt_installer:obfuscate_str */"com.rareventure.gps2.GTG.Preferences.passwordTimeoutMS",
 					GTG.prefs.passwordTimeoutMS);
-			res.put(/* ttt_installer:obfuscate_str */"com.rareventure.gps2.GTG.Preferences.writeGpsWakeLockDebug",
-					GTG.prefs.writeGpsWakeLockDebug);
+			res.put(/* ttt_installer:obfuscate_str */"com.rareventure.gps2.GTG.Preferences.writeFileLogDebug",
+					GTG.prefs.writeFileLogDebug);
 
 			res.put(/* ttt_installer:obfuscate_str */"com.rareventure.gps2.reviewer.map.OsmMapGpsTrailerReviewerMapActivity.Preferences.lastLon",
 					OsmMapGpsTrailerReviewerMapActivity.prefs.lastLon);
@@ -803,8 +801,8 @@ public class GTG {
 				GTG.prefs.useMetric = Boolean.parseBoolean(value);
 			else if(name.equals(/* ttt_installer:obfuscate_str */"com.rareventure.gps2.GTG.Preferences.passwordTimeoutMS"))
 				GTG.prefs.passwordTimeoutMS = Long.parseLong(value);
-			else if(name.equals(/* ttt_installer:obfuscate_str */"com.rareventure.gps2.GTG.Preferences.writeGpsWakeLockDebug"))
-				GTG.prefs.writeGpsWakeLockDebug = Boolean.parseBoolean(value);
+			else if(name.equals(/* ttt_installer:obfuscate_str */"com.rareventure.gps2.GTG.Preferences.writeFileLogDebug"))
+				GTG.prefs.writeFileLogDebug = Boolean.parseBoolean(value);
 
 			else if(name.equals(/* ttt_installer:obfuscate_str */"com.rareventure.gps2.reviewer.map.OsmMapGpsTrailerReviewerMapActivity.Preferences.lastLon"))
 				OsmMapGpsTrailerReviewerMapActivity.prefs.lastLon = Double.parseDouble(value);
@@ -1331,7 +1329,7 @@ public class GTG {
 		/**
 		 * If true will write to the gps wake lock debug file
 		 */
-		public boolean writeGpsWakeLockDebug = false;
+		public boolean writeFileLogDebug = false;
 	}
 	
 	public static int COMPASS_DATA_XOR = -1016932754;
