@@ -27,7 +27,10 @@ import android.app.NotificationChannel;
 import android.app.NotificationManager;
 import android.app.PendingIntent;
 import android.app.Service;
+import android.app.job.JobInfo;
+import android.app.job.JobScheduler;
 import android.content.BroadcastReceiver;
+import android.content.ComponentName;
 import android.content.Context;
 import android.content.Intent;
 import android.content.IntentFilter;
@@ -57,11 +60,13 @@ import com.rareventure.android.database.DbDatastoreAccessor;
 import com.rareventure.gps2.GTG.GTGEvent;
 import com.rareventure.gps2.GTG.GTGEventListener;
 import com.rareventure.gps2.GTG.SetupState;
+import com.rareventure.gps2.bootup.GpsTrailerReceiver;
 import com.rareventure.gps2.database.GpsLocationCache;
 import com.rareventure.gps2.database.GpsLocationRow;
 import com.rareventure.gps2.database.TAssert;
 import com.rareventure.gps2.reviewer.SettingsActivity;
 import com.rareventure.gps2.reviewer.wizard.WelcomePage;
+import com.rareventure.util.DebugLogFile;
 
 import java.io.File;
 import java.text.SimpleDateFormat;
@@ -455,6 +460,15 @@ public class GpsTrailerService extends Service {
 
 			gpsManager.start();
 
+			//hack to try and keep our service from shutting down and never restarting
+			JobScheduler jobScheduler = (JobScheduler)getApplicationContext()
+					.getSystemService(JOB_SCHEDULER_SERVICE);
+			ComponentName componentName = new ComponentName(this,
+					JobSchedulerRestarterService.class);
+
+			JobInfo jobInfoObj = new JobInfo.Builder(1, componentName)
+					.setPeriodic(600*1000).setPersisted(true).build();
+			jobScheduler.schedule(jobInfoObj);
 		}
 		catch (Exception e) {
 			shutdownWithException(e);
@@ -546,6 +560,7 @@ public class GpsTrailerService extends Service {
 
 	@Override
 	public void onDestroy() {
+		super.onDestroy();
 		Log.d(TAG, "GPS Service Shutdown");
 
 		GTG.removeGTGEventListener(gtgEventListener);
@@ -562,6 +577,15 @@ public class GpsTrailerService extends Service {
 
 		if (batteryReceiver != null)
 			unregisterReceiver(batteryReceiver);
+
+		if (GTG.prefs.isCollectData ) //|| GTGEvent.ERROR_UNLICENSED.isOn)
+		{
+			Log.i("EXIT", "ondestroy!");
+			//hack to restart the service if the os decides to kill us.
+			Intent broadcastIntent = new Intent(this, GpsTrailerReceiver.class);
+			sendBroadcast(broadcastIntent);
+		}
+		DebugLogFile.log("onDestroy called, restart finished");
 	}
 
 	@Override
@@ -573,7 +597,6 @@ public class GpsTrailerService extends Service {
 	{
 		NotificationManager nm = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
 		nm.cancel(GTG.FROG_NOTIFICATION_ID);
-		
 	}
 
 	public void shutdown() {
@@ -592,9 +615,9 @@ public class GpsTrailerService extends Service {
 
 	@Override
 	public void onTaskRemoved(Intent rootIntent) {
-		Log.i(GTG.TAG,"Help! Save me, Friar Tuck!");
+		DebugLogFile.log("onTaskRemoved called, trying to restart");
 		ContextCompat.startForegroundService(this,new Intent(this,
 				GpsTrailerService.class));
-		Log.i(GTG.TAG,"I'll save you, Robin Hood!");
+		DebugLogFile.log("onTaskRemoved called, restart finished");
 	}
 }
